pub struct Prediction {
pub id: String,
pub model: String,
pub version: String,
pub input: Value,
pub status: PredictionStatus,
pub created_at: String,
pub urls: PredictionUrls,
pub output: Option<Value>,
}Expand description
Details for a specific prediction
Fields
id: StringId of the prediction
model: StringModel used during the prediction
version: StringSpecific version used during prediction
input: ValueThe inputs provided for the specific prediction
status: PredictionStatusThe current status of the prediction
created_at: StringThe created time for the prediction
urls: PredictionUrlsUrls to either retrieve or cancel details for this prediction
output: Option<Value>The output of the prediction if completed
Implementations
Sourceimpl Prediction
impl Prediction
Sourcepub async fn reload(&mut self) -> Result<()>
pub async fn reload(&mut self) -> Result<()>
Leverage the get url provided, to refresh struct attributes
Sourcepub async fn get_status(&mut self) -> PredictionStatus
pub async fn get_status(&mut self) -> PredictionStatus
Get the status for the current prediction
Sourcepub async fn get_stream(
&mut self,
) -> Result<EventStream<impl Stream<Item = Result<Bytes>>>>
pub async fn get_stream( &mut self, ) -> Result<EventStream<impl Stream<Item = Result<Bytes>>>>
Get the stream from a prediction